==> jc-1.4.0.tar.gz: ppg/util/StringItem.h <==
// class ppg.util.StringItem

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5146bf5a25ced51e ppg_util_Item
// @dep_class 47dee1898b7c014b ppg_util_StringItem

// header file dependencies
// @dep_header ppg_util_Item

#include "ppg/util/Item.h"

#ifndef _JC_ppg_util_StringItem_H_
#define _JC_ppg_util_StringItem_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_util_StringItem$sub_refs	_jc_ppg_util_StringItem$sub_refs;
typedef struct _jc_ppg_util_StringItem$sub_nonrefs	_jc_ppg_util_StringItem$sub_nonrefs;
typedef struct _jc_ppg_util_StringItem$refs	_jc_ppg_util_StringItem$refs;
typedef struct _jc_ppg_util_StringItem$nonrefs	_jc_ppg_util_StringItem$nonrefs;
typedef struct _jc_ppg_util_StringItem$object	_jc_ppg_util_StringItem$object;

typedef const struct _jc_ppg_util_StringItem$vmethods	_jc_ppg_util_StringItem$vmethods;
typedef const struct _jc_ppg_util_StringItem$vtable	_jc_ppg_util_StringItem$vtable;
typedef const struct _jc_ppg_util_StringItem$vtype	_jc_ppg_util_StringItem$vtype;

// Constructors
extern void _jc_ppg_util_StringItem$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_util_StringItem$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_ppg_util_StringItem$method$appendString$9b5e5320a5323d14(_jc_env *, struct _jc_ppg_util_StringItem$object *, struct _jc_java_lang_String$object *);
extern jint _jc_ppg_util_StringItem$method$formatN$d2e3422217490f28(_jc_env *, struct _jc_ppg_util_StringItem$object *, jint, jint, jint, jint, jboolean, jboolean);
extern jint _jc_ppg_util_StringItem$method$sendOutput$7012ec94d3c70bcd(_jc_env *, struct _jc_ppg_util_StringItem$object *, struct _jc_java_io_Writer$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_ppg_util_StringItem$method_info$appendString$9b5e5320a5323d14;
extern _jc_method _jc_ppg_util_StringItem$method_info$formatN$d2e3422217490f28;
extern _jc_method _jc_ppg_util_StringItem$method_info$sendOutput$7012ec94d3c70bcd;

// Virtual methods structure
struct _jc_ppg_util_StringItem$vmethods {
	void	(*appendString$9b5e5320a5323d14)(_jc_env *, struct _jc_ppg_util_StringItem$object *, struct _jc_java_lang_String$object *);
	jint	(*formatN$d2e3422217490f28)(_jc_env *, struct _jc_ppg_util_StringItem$object *, jint, jint, jint, jint, jboolean, jboolean);
	jint	(*sendOutput$7012ec94d3c70bcd)(_jc_env *, struct _jc_ppg_util_StringItem$object *, struct _jc_java_io_Writer$object *, jint, jint);
};

// Vtable
struct _jc_ppg_util_StringItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_util_Item$vmethods	ppg_util_Item;
	_jc_ppg_util_StringItem$vmethods	ppg_util_StringItem;
};

// Vtype
struct _jc_ppg_util_StringItem$vtype {
	_jc_type			type;
	_jc_ppg_util_StringItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_util_StringItem$sub_refs {
	struct _jc_java_lang_String$object	*s;
};

// Reference instance fields (object)
struct _jc_ppg_util_StringItem$refs {
    _jc_ppg_util_StringItem$sub_refs	ppg_util_StringItem;
    _jc_ppg_util_Item$sub_refs	ppg_util_Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_util_StringItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_util_StringItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_util_Item$sub_nonrefs	ppg_util_Item;
    _jc_ppg_util_StringItem$sub_nonrefs	ppg_util_StringItem;
};

// Object instance structure
struct _jc_ppg_util_StringItem$object {
	_jc_ppg_util_StringItem$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_util_StringItem$vtype	*vtype;
	_jc_ppg_util_StringItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_util_StringItem$vtype _jc_ppg_util_StringItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_util_StringItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_util_StringItem$class_object;

#endif	/* _JC_ppg_util_StringItem_H_ */

==> jc-1.4.6.tar.gz: ppg/util/StringItem.h <==
// class ppg.util.StringItem

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5146bf5a25ced51e ppg_util_Item
// @dep_class 47dee1898b7c014b ppg_util_StringItem

// header file dependencies
// @dep_header ppg_util_Item

#include "ppg/util/Item.h"

#ifndef _JC_ppg_util_StringItem_H_
#define _JC_ppg_util_StringItem_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_util_StringItem$sub_refs	_jc_ppg_util_StringItem$sub_refs;
typedef struct _jc_ppg_util_StringItem$sub_nonrefs	_jc_ppg_util_StringItem$sub_nonrefs;
typedef struct _jc_ppg_util_StringItem$refs	_jc_ppg_util_StringItem$refs;
typedef struct _jc_ppg_util_StringItem$nonrefs	_jc_ppg_util_StringItem$nonrefs;
typedef struct _jc_ppg_util_StringItem$object	_jc_ppg_util_StringItem$object;

typedef const struct _jc_ppg_util_StringItem$vmethods	_jc_ppg_util_StringItem$vmethods;
typedef const struct _jc_ppg_util_StringItem$vtable	_jc_ppg_util_StringItem$vtable;
typedef const struct _jc_ppg_util_StringItem$vtype	_jc_ppg_util_StringItem$vtype;

// Constructors
extern void _jc_ppg_util_StringItem$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_util_StringItem$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_ppg_util_StringItem$method$appendString$9b5e5320a5323d14(_jc_env *, struct _jc_ppg_util_StringItem$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jint _jc_ppg_util_StringItem$method$formatN$d2e3422217490f28(_jc_env *, struct _jc_ppg_util_StringItem$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;
extern jint _jc_ppg_util_StringItem$method$sendOutput$7012ec94d3c70bcd(_jc_env *, struct _jc_ppg_util_StringItem$object *, struct _jc_java_io_Writer$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_util_StringItem$method_info$appendString$9b5e5320a5323d14;
extern _jc_method _jc_ppg_util_StringItem$method_info$formatN$d2e3422217490f28;
extern _jc_method _jc_ppg_util_StringItem$method_info$sendOutput$7012ec94d3c70bcd;

// Virtual methods structure
struct _jc_ppg_util_StringItem$vmethods {
	void	(*appendString$9b5e5320a5323d14)(_jc_env *, struct _jc_ppg_util_StringItem$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	jint	(*formatN$d2e3422217490f28)(_jc_env *, struct _jc_ppg_util_StringItem$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;
	jint	(*sendOutput$7012ec94d3c70bcd)(_jc_env *, struct _jc_ppg_util_StringItem$object *, struct _jc_java_io_Writer$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_util_StringItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_util_Item$vmethods	ppg_util_Item;
	_jc_ppg_util_StringItem$vmethods	ppg_util_StringItem;
};

// Vtype
struct _jc_ppg_util_StringItem$vtype {
	_jc_type			type;
	_jc_ppg_util_StringItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_util_StringItem$sub_refs {
	struct _jc_java_lang_String$object	*s;
};

// Reference instance fields (object)
struct _jc_ppg_util_StringItem$refs {
    _jc_ppg_util_StringItem$sub_refs	ppg_util_StringItem;
    _jc_ppg_util_Item$sub_refs	ppg_util_Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_util_StringItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_util_StringItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_util_Item$sub_nonrefs	ppg_util_Item;
    _jc_ppg_util_StringItem$sub_nonrefs	ppg_util_StringItem;
};

// Object instance structure
struct _jc_ppg_util_StringItem$object {
	_jc_ppg_util_StringItem$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_util_StringItem$vtype	*vtype;
	_jc_ppg_util_StringItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_util_StringItem$vtype _jc_ppg_util_StringItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_util_StringItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_util_StringItem$class_object;

#endif	/* _JC_ppg_util_StringItem_H_ */
